@@ -134,6 +134,7 @@ namespace LongoMatch.Gui.Component
 		protected override void EditSelected() {
 			EditCategoryDialog dialog = new EditCategoryDialog(ts);
 			dialog.Category = selected[0];
+			dialog.Template = Template;
 			dialog.HotKeysList = hkList;
 			dialog.TransientFor = (Gtk.Window) Toplevel;
 			dialog.Run();
@@ -234,6 +235,8 @@ namespace LongoMatch.Gui.Component
 			
 			desc = Catalog.GetString ("Game periods") + " (eg: 1 2 ex1 ex2) ";
 			res = MessagesHelpers.QueryMessage (this, desc, "", String.Join (" ", Template.GamePeriods));
+			if (res == null)
+				return;
 			
 			periods = new List<string> (res.Split(' '));
 			if (periods.Count == 0) {
