@@ -146,8 +146,7 @@ namespace LongoMatch.Gui
 			}
 			if(response ==(int)ResponseType.Ok) {
 				if (!vep.SplitFiles) {
-					jobs.Add(new EditionJob(playlist, vep.EncodingSettings,
-					                        vep.EnableAudio, vep.TitleOverlay));
+					jobs.Add(new EditionJob(playlist, vep.EncodingSettings));
 				} else {
 					int i = 0;
 					foreach (PlayListPlay play in playlist) {
@@ -158,7 +157,7 @@ namespace LongoMatch.Gui
 						
 						pl.Add(play);
 						settings.OutputFile = Path.Combine (vep.OutputDir, filename);
-						jobs.Add(new EditionJob(pl, settings, vep.EnableAudio, vep.TitleOverlay));
+						jobs.Add(new EditionJob(pl, settings));
 						i++;
 					}
 				}
